
# Resources
- signature overview https://docs.gnosis-safe.io/contracts/signatures
- safeTxHash https://help.gnosis-safe.io/en/articles/5246870-what-is-the-safe-transaction-hash-safetxhash
- safeTxHash encoding https://github.com/safe-global/safe-contracts/blob/v1.1.1/contracts/GnosisSafe.sol

# Source Code
- contracts
    https://github.com/safe-global/safe-contracts/blob/v1.1.1/contracts/GnosisSafe.sol
    https://github.com/safe-global/safe-contracts/blob/v1.3.0/contracts/GnosisSafe.sol
    https://github.com/safe-global/safe-contracts/blob/v1.3.0/src/utils/execution.ts
- specifications
    https://eips.ethereum.org/EIPS/eip-712#definition-of-domainseparator
